value_stream library
Classes
-
DataStream<
T> - A broadcast Stream with access to the latest emitted value. Does explicitly NOT handle errors to provide a direct and simple access to the value.
-
EventSnapshot<
T> -
EventStream<
T> - A broadcast Stream with access to the latest emitted value, with error handling.
-
ValueStream<
T> - Abstract base class for a broadcast Stream with access to the latest emitted value.
Functions
-
isNullable<
T> () → bool - Whether the specified type is nullable.